from datetime import date

from pydantic import BaseModel


class InstallmentTerm(BaseModel):
    parts: int = 4
    part_amount: float = 3500000.0
    upfront_amount: float = 4300000.0


class Installment(BaseModel):
    identifier: str
    name: str
    paid_parts: int
    overall_due_date: date
    part_amount: int
    parts: int
    grace_days: int
